@@ -10,6 +10,7 @@ import pathlib
 import random
 import shutil
 import subprocess
+import sys
 import time
 import urllib
 
@@ -113,6 +114,19 @@ def readBinFile(file):
     return data
 
 
+def checkLockFile(lockFile):
+    if os.path.isfile(lockFile):
+        isDebug = sys.executable.endswith("python.exe")
+        if isDebug:
+            print(f"不支持重复执行 {lockFile}")
+            while True:
+                if input("当前调试模式下，输入unlock可继续：") == "unlock":
+                    break
+        else:
+            raise Exception(f"不支持重复执行 {lockFile}")
+    writeFile(lockFile, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
+
+
 def jsonDumps(value):
     return json.dumps(value, ensure_ascii=False, sort_keys=True, separators=(',', ':'))
 
